@@ -17,7 +17,6 @@
 */
 
 #include "propertiesbrowser.h"
-#include "propertiesbrowser.moc"
 
 #include "settings.h"
 
@@ -29,24 +28,17 @@
 #include <stepcore/solver.h>
 #include <stepcore/types.h>
 #include <QAbstractItemModel>
-#include <QStandardItemModel>
 #include <QItemEditorFactory>
 #include <QTreeView>
 #include <QMouseEvent>
 #include <KLineEdit>
 #include <QHBoxLayout>
 #include <QApplication>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KComboBox>
 #include <KColorButton>
 
-class ChoicesModel: public QStandardItemModel
-{
-public:
-    ChoicesModel(QObject* parent = 0): QStandardItemModel(parent) {}
-};
-
-Q_DECLARE_METATYPE(ChoicesModel*)
+#include "choicesmodel.h"
 
 class PropertiesBrowserModel: public QAbstractItemModel
 {
@@ -379,7 +371,7 @@ bool PropertiesBrowserModel::setData(const QModelIndex &index, const QVariant &v
                      * {} else if(p->userTypeId() == qMetaTypeId<StepCore::Vector2dList >())
                         ve = QVariant::fromValue(StepCore::Vector2dList());*/
                     } else {
-                        kDebug() << "Unhandled property variance type" << endl;
+//                         kDebug() << "Unhandled property variance type" << endl;
                         return false;
                     }
                     if(!ok) return false;
@@ -389,13 +381,13 @@ bool PropertiesBrowserModel::setData(const QModelIndex &index, const QVariant &v
                         if(p->userTypeId() == QMetaType::Double) {
                             vv = 0;
                         } else if(p->userTypeId() == qMetaTypeId<StepCore::Vector2d>()) {
-                            StepCore::Vector2d svv(0);
+                            StepCore::Vector2d svv = StepCore::Vector2d::Zero();
                             vv = QVariant::fromValue(svv);
                         /* XXX
                          * } else if(p->userTypeId() == qMetaTypeId<StepCore::Vector2dList >())
                             ve = QVariant::fromValue(StepCore::Vector2dList());*/
                         } else {
-                            kDebug() << "Unhandled property variance type" << endl;
+                            qWarning("Unhandled property variance type");
                             return false;
                         }
                     }
@@ -441,7 +433,7 @@ QModelIndex PropertiesBrowserModel::index(int row, int column, const QModelIndex
 QModelIndex PropertiesBrowserModel::parent(const QModelIndex& index) const
 {
     if(index.isValid() && index.internalId() != 0)
-        return createIndex(index.internalId()-1, 0, 0);
+        return createIndex(index.internalId()-1, 0, nullptr);
     return QModelIndex();
 }
 
